#[non_exhaustive]pub enum Error {
InvalidBlob,
EpochController,
EpochControllerNoAck,
EpochControllerTeardown(u32),
StreamingEngine(u16),
BusInterface(u8),
Fault(u32),
}Expand description
NPU error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidBlob
The buffer passed as a blob does not start with the blob magic.
EpochController
The epoch controller reported an error (illegal opcode, bus fault).
EpochControllerNoAck
The epoch controller waited for a unit acknowledge that never came.
EpochControllerTeardown(u32)
Epoch-controller CLR/CONFCLR teardown did not complete. Contains the final raw EPOCHCTRL.CTRL value; bit 1 identifies CLR and bit 30 identifies CONFCLR.
StreamingEngine(u16)
One or more streaming engines reported an error (bitmask by engine).
BusInterface(u8)
One or more bus interfaces reported an error (bitmask by unit).
Fault(u32)
Unexpected interrupt source(s) (raw INTCTRL bitmask).